==> intel-compute-runtime_19.13.12717.orig.tar.gz: compute-runtime-19.13.12717/unit_tests/api/api_tests_wrapper1.cpp <==
/*
 * Copyright (C) 2018 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "unit_tests/api/cl_build_program_tests.inl"
#include "unit_tests/api/cl_clone_kernel_tests.inl"
#include "unit_tests/api/cl_compile_program_tests.inl"
#include "unit_tests/api/cl_create_command_queue_tests.inl"
#include "unit_tests/api/cl_create_context_from_type_tests.inl"
#include "unit_tests/api/cl_create_context_tests.inl"
#include "unit_tests/api/cl_create_kernel_tests.inl"
#include "unit_tests/api/cl_create_kernels_in_program_tests.inl"
#include "unit_tests/api/cl_create_perf_counters_command_queue_tests.inl"
#include "unit_tests/api/cl_create_pipe_tests.inl"
#include "unit_tests/api/cl_create_program_with_binary_tests.inl"
#include "unit_tests/api/cl_create_sampler_tests.inl"
#include "unit_tests/api/cl_create_sampler_with_properties_tests.inl"
#include "unit_tests/api/cl_create_sub_buffer_tests.inl"
#include "unit_tests/api/cl_create_sub_devices_tests.inl"
#include "unit_tests/api/cl_create_user_event_tests.inl"
#include "unit_tests/api/cl_enqueue_barrier_tests.inl"
#include "unit_tests/api/cl_enqueue_barrier_with_wait_list_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_buffer_rect_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_buffer_to_image_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_image_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_image_to_buffer_tests.inl"
#include "unit_tests/api/cl_enqueue_fill_buffer_tests.inl"
#include "unit_tests/api/cl_enqueue_fill_image_tests.inl"
#include "unit_tests/api/cl_enqueue_image_tests.inl"
#include "unit_tests/api/cl_enqueue_map_buffer_tests.inl"
#include "unit_tests/api/cl_enqueue_map_image_tests.inl"
#include "unit_tests/api/cl_enqueue_marker_tests.inl"
#include "unit_tests/api/cl_enqueue_marker_with_wait_list_tests.inl"

==> intel-compute-runtime_19.39.14278.orig.tar.gz: compute-runtime-19.39.14278/unit_tests/api/api_tests_wrapper1.cpp <==
/*
 * Copyright (C) 2018-2019 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "unit_tests/api/cl_add_comment_to_aub_tests.inl"
#include "unit_tests/api/cl_build_program_tests.inl"
#include "unit_tests/api/cl_clone_kernel_tests.inl"
#include "unit_tests/api/cl_compile_program_tests.inl"
#include "unit_tests/api/cl_create_command_queue_tests.inl"
#include "unit_tests/api/cl_create_context_from_type_tests.inl"
#include "unit_tests/api/cl_create_context_tests.inl"
#include "unit_tests/api/cl_create_kernel_tests.inl"
#include "unit_tests/api/cl_create_kernels_in_program_tests.inl"
#include "unit_tests/api/cl_create_perf_counters_command_queue_tests.inl"
#include "unit_tests/api/cl_create_pipe_tests.inl"
#include "unit_tests/api/cl_create_program_with_binary_tests.inl"
#include "unit_tests/api/cl_create_sampler_tests.inl"
#include "unit_tests/api/cl_create_sampler_with_properties_tests.inl"
#include "unit_tests/api/cl_create_sub_buffer_tests.inl"
#include "unit_tests/api/cl_create_sub_devices_tests.inl"
#include "unit_tests/api/cl_create_user_event_tests.inl"
#include "unit_tests/api/cl_enqueue_barrier_tests.inl"
#include "unit_tests/api/cl_enqueue_barrier_with_wait_list_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_buffer_rect_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_buffer_to_image_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_image_tests.inl"
#include "unit_tests/api/cl_enqueue_copy_image_to_buffer_tests.inl"
#include "unit_tests/api/cl_enqueue_fill_buffer_tests.inl"
#include "unit_tests/api/cl_enqueue_fill_image_tests.inl"
#include "unit_tests/api/cl_enqueue_image_tests.inl"
#include "unit_tests/api/cl_enqueue_map_buffer_tests.inl"
#include "unit_tests/api/cl_enqueue_map_image_tests.inl"
#include "unit_tests/api/cl_enqueue_marker_tests.inl"
#include "unit_tests/api/cl_enqueue_marker_with_wait_list_tests.inl"
#include "unit_tests/api/cl_function_pointers_tests.inl"
#include "unit_tests/api/cl_unified_shared_memory_tests.inl"
